@@ -12,8 +12,8 @@ extern "C" {
 /*
   Color quantum is [0..65535].
 */
-#define DownScale(quantum)  ((quantum)/256)
-#define HexColorFormat "#%04x%04x%04x"
+#define DownScale(quantum)  ((quantum)/257)
+#define HexColorFormat "#%04x%04x%04x%04x"
 #define MaxRGB  65535L
 #define QuantumDepth  16
 #define UpScale(quantum)  (257*(quantum))
@@ -26,11 +26,11 @@ typedef unsigned short Quantum;
   Color quantum is [0..255].
 */
 #define DownScale(quantum)  (quantum)
-#define HexColorFormat "#%02x%02x%02x"
+#define HexColorFormat "#%02x%02x%02x%02x"
 #define MaxRGB  255L
 #define QuantumDepth  8
 #define UpScale(quantum)  (quantum)
-#define XDownScale(color)  ((color)/256)
+#define XDownScale(color)  ((color)/257)
 #define XUpScale(color)  (257*(color))
 
 typedef unsigned char Quantum;
@@ -50,6 +50,17 @@ typedef unsigned char Quantum;
 /*
   Typedef declarations.
 */
+typedef struct _AffineMatrix
+{
+  double
+    sx,
+    rx,
+    ry,
+    sy,
+    tx,
+    ty;
+} AffineMatrix;
+
 typedef struct _Ascii85Info
 {
   int
@@ -76,6 +87,13 @@ typedef struct _PixelPacket
     green,
     blue,
     opacity;
+#else
+#if defined(macintosh)
+  Quantum
+    opacity,
+    red,
+    green,
+    blue;
 #else
   Quantum
     blue,
@@ -83,6 +101,7 @@ typedef struct _PixelPacket
     red,
     opacity;
 #endif
+#endif
 } PixelPacket;
 
 typedef struct _RectangleInfo
@@ -96,37 +115,6 @@ typedef struct _RectangleInfo
     y;
 } RectangleInfo;
 
-typedef struct _AnnotateInfo
-{
-  char
-    *geometry,
-    *text,
-    *font,
-    *density;
-
-  unsigned int
-    antialias;
-
-  GravityType
-    gravity;
-
-  double
-    pointsize,
-    degrees,
-    affine[6];
-
-  PixelPacket
-    fill,
-    stroke,
-    box;
-
-  DecorationType
-    decorate;
-
-  unsigned int
-    signature;
-} AnnotateInfo;
-
 typedef struct _BoundingBox
 {
   double
@@ -152,7 +140,7 @@ typedef struct _BlobInfo
     extent,
     quantum;
 
-  unsigned int
+  unsigned long
     signature;
 } BlobInfo;
 
@@ -165,41 +153,28 @@ typedef struct _ChromaticityInfo
     white_point;
 } ChromaticityInfo;
 
-typedef struct _ColorlistInfo
-{
-  char
-    *name;
-
-  Quantum
-    red,
-    green,
-    blue;
-} ColorlistInfo;
-
 typedef struct _ExceptionInfo
 {
   ExceptionType
     severity;
 
   char
-    *message,
-    *qualifier;
+    *reason,
+    *description;
 
-  unsigned int
+  unsigned long
     signature;
 } ExceptionInfo;
 
 typedef struct _FrameInfo
 {
-  int
-    x,
-    y;
-
   unsigned int
     width,
     height;
 
   int
+    x,
+    y,
     inner_bevel,
     outer_bevel;
 } FrameInfo;
@@ -251,18 +226,18 @@ typedef struct _MontageInfo
     border_color,
     matte_color;
 
-  unsigned int
+  unsigned long
     signature;
 } MontageInfo;
 
 typedef struct _ProfileInfo
 {
-  char
-    *name;
-
   unsigned int
     length;
 
+  char
+    *name;
+
   unsigned char
     *info;
 } ProfileInfo;
@@ -293,7 +268,7 @@ typedef struct _TimerInfo
   TimerState
     state;
 
-  unsigned int
+  unsigned long
     signature;
 } TimerInfo;
 
@@ -409,7 +384,7 @@ typedef struct _Image
   double
     blur;
 
-  unsigned long
+  size_t
     total_colors;
 
   unsigned int
@@ -427,7 +402,7 @@ typedef struct _Image
     magick_rows;
 
   int
-    restart_animation_here,
+    start_loop,
     taint;
 
   TimerInfo
@@ -455,49 +430,16 @@ typedef struct _Image
     *client_data;
 
   unsigned int
-    orphan,
-    signature;
+    orphan;
 
   struct _Image
     *previous,
     *list,
     *next;
-} Image;
 
-typedef struct _DrawInfo
-{
-  char
-    *primitive,
-    *font;
-
-  unsigned int
-    antialias;
-
-  GravityType
-    gravity;
-
-  double
-    opacity,
-    linewidth,
-    pointsize,
-    angle,
-    affine[6];
-
-  PixelPacket
-    fill,
-    stroke,
-    box,
-    border_color;
-
-  DecorationType
-    decorate;
-
-  Image
-    *tile;
-
-  unsigned int
+  unsigned long
     signature;
-} DrawInfo;
+} Image;
 
 typedef struct _ImageInfo
 {
@@ -559,15 +501,13 @@ typedef struct _ImageInfo
     antialias;
 
   double
-    pointsize,
-    affine[6];
+    pointsize;
 
   double
     fuzz;
 
   PixelPacket
-    fill,
-    stroke,
+    pen,
     background_color,
     border_color,
     matte_color;
@@ -582,25 +522,9 @@ typedef struct _ImageInfo
   ColorspaceType
     colorspace;
 
-  /*
-    Animation members.
-  */
-  char
-    *dispose,
-    *delay,
-    *iterations;
-
-  unsigned int
-    decode_all_MNG_objects,
-    coalesce_frames,
-    insert_backdrops;
-
   /*
     Miscellaneous members.
   */
-  unsigned int
-    verbose;
-
   PreviewType
     preview_type;
 
@@ -611,12 +535,17 @@ typedef struct _ImageInfo
     group;
 
   unsigned int
-    ping;
+    ping,
+    verbose,
+    debug;
 
   int
     (*fifo)(const Image *,const void *,const size_t);
 
-  unsigned int
+  void
+    *client_data;
+
+  unsigned long
     signature;
 } ImageInfo;
 
@@ -625,6 +554,9 @@ typedef struct _MagickInfo
   char
     *tag;
 
+  ImageInfo
+    *image_info;
+
   Image
     *(*decoder)(const ImageInfo *,ExceptionInfo *);
 
@@ -633,21 +565,22 @@ typedef struct _MagickInfo
     (*magick)(const unsigned char *,const unsigned int),
     adjoin,
     blob_support,
-    raw;
+    raw,
+    stealth;
 
   char
     *description,
     *module;
 
   void
-    *data;
-
-  unsigned int
-    signature;
+    *client_data;
 
   struct _MagickInfo
     *previous,
     *next;
+
+  unsigned long
+    signature;
 } MagickInfo;
 
 /*
@@ -673,29 +606,21 @@ extern MagickExport const char
   *SaveImageText,
   *SaveImagesText,
   *WriteBinaryType;
-
-extern MagickExport const ColorlistInfo
-  XPMColorlist[236],
-  XColorlist[764];
 
 /*
   Image utilities methods.
 */
-extern MagickExport AnnotateInfo
-  *CloneAnnotateInfo(const ImageInfo *,const AnnotateInfo *);
-
 extern MagickExport char 
-  *GetImageMagick(const unsigned char *);
-
-extern MagickExport DrawInfo
-  *CloneDrawInfo(const ImageInfo *,const DrawInfo *);
+  *GetImageMagick(const unsigned char *,const unsigned int),
+  *GetMagickConfigurePath(const char *),
+  *GetMagickVersion(unsigned int *);
 
 extern MagickExport Image
   *AddNoiseImage(Image *,const NoiseType,ExceptionInfo *),
   *AllocateImage(const ImageInfo *),
   *AppendImages(Image *,const unsigned int,ExceptionInfo *),
   *AverageImages(Image *,ExceptionInfo *),
-  *BlurImage(Image *,const unsigned int,ExceptionInfo *),
+  *BlurImage(Image *,const double,const double,ExceptionInfo *),
   *BorderImage(Image *,const RectangleInfo *,ExceptionInfo *),
   *ChopImage(Image *,const RectangleInfo *,ExceptionInfo *),
   *CloneImage(Image *,const unsigned int,const unsigned int,const unsigned int,
@@ -708,8 +633,8 @@ extern MagickExport Image
   *CropImage(Image *,const RectangleInfo *,ExceptionInfo *),
   *DeconstructImages(Image *,ExceptionInfo *),
   *DespeckleImage(Image *,ExceptionInfo *),
-  *EdgeImage(Image *,const unsigned int,ExceptionInfo *),
-  *EmbossImage(Image *,const unsigned int,ExceptionInfo *),
+  *EdgeImage(Image *,const double,ExceptionInfo *),
+  *EmbossImage(Image *,const double,const double,ExceptionInfo *),
   *EnhanceImage(Image *,ExceptionInfo *),
   *FlipImage(Image *,ExceptionInfo *),
   *FlopImage(Image *,ExceptionInfo *),
@@ -719,22 +644,24 @@ extern MagickExport Image
   *ImplodeImage(Image *,const double,ExceptionInfo *),
   **ListToGroupImage(Image *,unsigned int *),
   *MagnifyImage(Image *,ExceptionInfo *),
-  *MedianFilterImage(Image *,const unsigned int,ExceptionInfo *),
+  *MedianFilterImage(Image *,const double,ExceptionInfo *),
   *MinifyImage(Image *,ExceptionInfo *),
   *MontageImages(Image *,const MontageInfo *,ExceptionInfo *),
   *MorphImages(Image *,const unsigned int,ExceptionInfo *),
   *MosaicImages(Image *,ExceptionInfo *),
-  *OilPaintImage(Image *,const unsigned int,ExceptionInfo *),
+  *OilPaintImage(Image *,const double,ExceptionInfo *),
   *PingImage(const ImageInfo *,ExceptionInfo *),
   *ReadImage(const ImageInfo *,ExceptionInfo *),
   *ReadImages(const ImageInfo *,ExceptionInfo *),
-  *ReduceNoiseImage(Image *,const unsigned int,ExceptionInfo *),
+  *ReduceNoiseImage(Image *,const double,ExceptionInfo *),
+  *ResizeImage(Image *,const unsigned int,const unsigned int,const FilterTypes,
+    const double,ExceptionInfo *),
   *RollImage(Image *,const int,const int,ExceptionInfo *),
   *RotateImage(Image *,const double,ExceptionInfo *),
   *SampleImage(Image *,const unsigned int,const unsigned int,ExceptionInfo *),
   *ScaleImage(Image *,const unsigned int,const unsigned int,ExceptionInfo *),
   *ShadeImage(Image *,const unsigned int,double,double,ExceptionInfo *),
-  *SharpenImage(Image *,const unsigned int,ExceptionInfo *),
+  *SharpenImage(Image *,const double,const double,ExceptionInfo *),
   *ShearImage(Image *,const double,const double,ExceptionInfo *),
   *SpreadImage(Image *,const unsigned int,ExceptionInfo *),
   *SteganoImage(Image *,Image *,ExceptionInfo *),
@@ -774,31 +701,30 @@ extern MagickExport PixelPacket
   *(*SetImagePixels)
     (Image *,const int,const int,const unsigned int,const unsigned int);
 
+extern MagickExport RectangleInfo
+  GetImageBoundingBox(Image *);
+
 extern MagickExport unsigned int
   AllocateImageColormap(Image *,const unsigned int),
   AnimateImages(const ImageInfo *image_info,Image *image),
-  AnnotateImage(Image *,const AnnotateInfo *),
-  ColorFloodfillImage(Image *,const DrawInfo *,const PixelPacket,const int x,
-    const int y,const PaintMethod),
+  ChannelImage(Image *,const ChannelType),
   CompositeImage(Image *,const CompositeOperator,Image *,const int,const int),
   ContrastImage(Image *,const unsigned int),
   DispatchImage(Image *,const int,const int,const unsigned int,
     const unsigned int,const char *,const StorageType,void *),
   DisplayImages(const ImageInfo *image_info,Image *image),
-  DrawImage(Image *,const DrawInfo *),
   EqualizeImage(Image *),
   GammaImage(Image *,const char *),
+  GetImageDepth(Image *),
   GetNumberScenes(const Image *),
   IsGeometry(const char *),
   IsGrayImage(Image *),
-  IsMatteImage(Image *),
+  IsImagesEqual(Image *,Image *),
   IsMonochromeImage(Image *),
+  IsOpaqueImage(Image *),
   IsPseudoClass(Image *),
   IsSubimage(const char *,const unsigned int),
-  IsTainted(const Image *),
-  LayerImage(Image *,const LayerType),
-  MatteFloodfillImage(Image *,const PixelPacket,const unsigned int,const int x,
-    const int y,const PaintMethod),
+  IsImageTainted(const Image *),
   ModulateImage(Image *,const char *),
   MogrifyImage(const ImageInfo *,const int,char **,Image **),
   MogrifyImages(const ImageInfo *,const int,char **,Image **),
@@ -807,13 +733,14 @@ extern MagickExport unsigned int
   OpaqueImage(Image *,const PixelPacket,const PixelPacket),
   PlasmaImage(Image *,const SegmentInfo *,int,int),
   PopImagePixels(const Image *,const QuantumType,unsigned char *),
-  ProfileImage(Image *,const ProfileType,const char *),
+  ProfileImage(Image *,const char *,const char *),
   PushImagePixels(const Image *,const QuantumType,const unsigned char *),
   QueryColorDatabase(const char *,PixelPacket *),
   RaiseImage(Image *,const RectangleInfo *,const int),
   ReadStream(const ImageInfo *,int (*)(const Image *,const void *,const size_t),
     ExceptionInfo *),
   RGBTransformImage(Image *,const ColorspaceType),
+  SetImageDepth(Image *,const unsigned int),
   SetImageInfo(ImageInfo *,const unsigned int),
   SignatureImage(Image *),
   SortColormapByIntensity(Image *),
@@ -833,31 +760,27 @@ extern MagickExport void
   CompressColormap(Image *),
   CycleColormapImage(Image *,const int),
   DescribeImage(Image *,FILE *,const unsigned int),
-  DestroyAnnotateInfo(AnnotateInfo *),
-  DestroyDrawInfo(DrawInfo *),
   DestroyImage(Image *),
   DestroyImageInfo(ImageInfo *),
   (*DestroyImagePixels)(Image *),
   DestroyImages(Image *),
   DestroyMagickInfo(void),
   DestroyMontageInfo(MontageInfo *),
-  GetAnnotateInfo(const ImageInfo *,AnnotateInfo *),
-  GetDrawInfo(const ImageInfo *,DrawInfo *),
   GetImageInfo(ImageInfo *),
   GetMontageInfo(const ImageInfo *,MontageInfo *),
   GetPageInfo(RectangleInfo *),
   GetPixelPacket(PixelPacket *),
   ListMagickInfo(FILE *),
-  MatteImage(Image *,Quantum),
   MagickIncarnate(const char *),
   Register8BIMImage(void),
+  RegisterARTImage(void),
   RegisterAVIImage(void),
   RegisterAVSImage(void),
   RegisterBIEImage(void),
   RegisterBMPImage(void),
   RegisterBMP24Image(void),
-  RegisterCACHEImage(void),
   RegisterCMYKImage(void),
+  RegisterCUTImage(void),
   RegisterDCMImage(void),
   RegisterDCXImage(void),
   RegisterDIBImage(void),
@@ -900,6 +823,7 @@ extern MagickExport void
   RegisterMIFFImage(void),
   RegisterMNGImage(void),
   RegisterMONOImage(void),
+  RegisterMPCImage(void),
   RegisterMTVImage(void),
   RegisterMVGImage(void),
   RegisterNETSCAPEImage(void),
@@ -952,6 +876,7 @@ extern MagickExport void
   RegisterTTFImage(void),
   RegisterTXTImage(void),
   RegisterUILImage(void),
+  RegisterURLImage(void),
   RegisterUYVYImage(void),
   RegisterVDAImage(void),
   RegisterVICARImage(void),
@@ -959,6 +884,7 @@ extern MagickExport void
   RegisterVIFFImage(void),
   RegisterVSTImage(void),
   RegisterWBMPImage(void),
+  RegisterWMFImage(void),
   RegisterWPGImage(void),
   RegisterXImage(void),
   RegisterXBMImage(void),
@@ -968,6 +894,7 @@ extern MagickExport void
   RegisterXWDImage(void),
   RegisterYUVImage(void),
   SetImage(Image *,Quantum),
+  SetImageOpacity(Image *,const unsigned int),
   SolarizeImage(Image *,const double),
   SyncImage(Image *),
   TextureImage(Image *,Image *),
@@ -975,12 +902,12 @@ extern MagickExport void
     double *),
   TransformImage(Image **,const char *,const char *),
   Unregister8BIMImage(void),
+  UnregisterARTImage(void),
   UnregisterAVIImage(void),
   UnregisterAVSImage(void),
   UnregisterBIEImage(void),
   UnregisterBMPImage(void),
   UnregisterBMP24Image(void),
-  UnregisterCACHEImage(void),
   UnregisterCMYKImage(void),
   UnregisterDCMImage(void),
   UnregisterDCXImage(void),
@@ -1024,6 +951,7 @@ extern MagickExport void
   UnregisterMIFFImage(void),
   UnregisterMNGImage(void),
   UnregisterMONOImage(void),
+  UnregisterMPCImage(void),
   UnregisterMTVImage(void),
   UnregisterMVGImage(void),
   UnregisterNETSCAPEImage(void),
@@ -1076,6 +1004,7 @@ extern MagickExport void
   UnregisterTTFImage(void),
   UnregisterTXTImage(void),
   UnregisterUILImage(void),
+  UnregisterURLImage(void),
   UnregisterUYVYImage(void),
   UnregisterVDAImage(void),
   UnregisterVICARImage(void),
@@ -1083,6 +1012,7 @@ extern MagickExport void
   UnregisterVIFFImage(void),
   UnregisterVSTImage(void),
   UnregisterWBMPImage(void),
+  UnregisterWMFImage(void),
   UnregisterWPGImage(void),
   UnregisterXImage(void),
   UnregisterXBMImage(void),
